@@ -24,7 +24,7 @@ class BaseCursor(metaclass=ABCMeta):
         retry_config: RetryConfig,
         **kwargs,
     ) -> None:
-        super(BaseCursor, self).__init__()
+        super().__init__()
         self._connection = connection
         self._converter = converter
         self._retry_config = retry_config
@@ -102,8 +102,6 @@ class BaseCursor(metaclass=ABCMeta):
         self,
         operation: str,
         parameters: Optional[Dict[str, Any]] = None,
-        limit: int = None,
-        consistent_read: bool = False,
     ):
         raise NotImplementedError  # pragma: no cover
 
@@ -137,9 +135,9 @@ class CursorIterator(metaclass=ABCMeta):
     DEFAULT_FETCH_SIZE: int = 1000
 
     def __init__(self, **kwargs) -> None:
-        super(CursorIterator, self).__init__()
+        super().__init__()
         self.arraysize: int = kwargs.get("arraysize", self.DEFAULT_FETCH_SIZE)
-        self._rownumber: Optional[int] = None
+        self._rownumber: Optional[int] = 0
 
     @property
     def arraysize(self) -> int:
