@@ -49,7 +49,7 @@ class DynamoDBStatementCompiler(SQLCompiler):
         ambiguous_table_name_map=None,
         **kwargs,
     ) -> str:
-        return super(DynamoDBStatementCompiler, self).visit_column(
+        return super().visit_column(
             column=column,
             add_to_result_map=add_to_result_map,
             include_table=False,
@@ -68,7 +68,7 @@ class DynamoDBStatementCompiler(SQLCompiler):
         result_map_targets=(),
         **kw,
     ):
-        return super(DynamoDBStatementCompiler, self).visit_label(
+        return super().visit_label(
             label=label,
             add_to_result_map=add_to_result_map,
             within_label_clause=within_label_clause,
@@ -184,20 +184,7 @@ class DynamoDBDialect(DefaultDialect):
         return opts
 
     def do_ping(self, dbapi_connection):
-        cursor = None
-        try:
-            cursor = dbapi_connection.cursor()
-            try:
-                cursor.execute(self._dialect_specific_select_one)
-            finally:
-                cursor.close()
-        except self.dbapi.Error as err:
-            if isinstance(err, OperationalError):
-                return True
-            else:
-                raise
-        else:
-            return True
+        return dbapi_connection.test_connection()
 
     def get_schema_names(self, connection, **kw):
         # DynamoDB does not have the concept of a schema
